%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% File name: PlotSystemAndModelOutput.m
%
% Description: Generates plots with system output signal and 
%              simulated output signals (using parameters obtained at
%              the end of the identification run) superimplosed in
%              the same plot. The input signals may also be shown.
%
% Inputs: Input signals, system output signals as well as simulated
%         model output signals.
%
% Outputs: Plots of system and model output signals.
%
% Author and copyright: Torbjrn Wigren
%                       Systems and Control
%                       Department of Information Technology
%                       Uppsala University
%                       Uppsala
%                       Sweden
%
% Revision log: Created 2003-04-27.
%
% Firm revision: revision 1.0, 2004-12-23.
%					  revision 2.0, 2005-08-24 (no changes).
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure

%
% Get dimension
%

numberOfOutputs=size(y_ms,1);
numberOfInputs=size(u,1);

%
% Plot
%

for i=1:numberOfOutputs
   subplot(numberOfOutputs+numberOfInputs,1,i)
   plot(SamplingInstances',[y(i,1:N)' y_ms(i,1:N)']);
   xlabel('time [s]')
   ytext=['y(' num2str(i) ')' ' and ' 'y_m(' num2str(i) ')'];
   ylabel(ytext);
end

for i=1:numberOfInputs
   subplot(numberOfOutputs+numberOfInputs,1,i+numberOfOutputs)
   plot(SamplingInstances',u(i,1:N)');
   xlabel('time [s]')
   ytext=['u(' num2str(i) ')'];
   ylabel(ytext);
end

