%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% File name: dfdx_m.m
%
% Description: This m-file generates the state sensitivity 
%              of the RHS of the ODE model. 
%
% Inputs: x_m - current model state
%         u - current input
%         theta - current parameter vector
%         allIndices - Matrix with all powers
%
% Outputs: dfdx_m - state sensitivities
%
% Author and copyright: Torbjrn Wigren
%                       Systems and Control
%                       Department of Information Technology
%                       Uppsala University
%                       Uppsala
%                       Sweden
%
% Revision log: Created 2003-05-20.
%
% Firm revision: revision 1.0, 2004-12-23.
%					  revision 2.0, 2005-08-24 (no changes).
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [dfdx_m]=f(x_m,u,theta,allIndices)

extendedState=[
   x_m;
   u];
numberOfIndicesInSum=size(allIndices,1);

nx=size(x_m,1);
dfdx_m=zeros(nx,nx);
for i=1:nx-1
   dfdx_m(i,i+1)=1;
end

for ii=1:nx

   sum=0;
      for i=1:numberOfIndicesInSum % Loop over all relevant combinations
   
      % add one term to the sum, corresponding to one index state
   
      thisIndex=allIndices(i,:);
      if thisIndex(1,ii)==0
         prod1=0;
      end;
      if thisIndex(1,ii)~=0
         prod1=thisIndex(1,ii);
      end;
   
      for j=1:size(thisIndex,2)
         if j==ii
            if thisIndex(1,j)>0
               for k=2:thisIndex(1,j)
                  prod1=prod1*extendedState(j,1);
               end            
            end
         end
         if j~=ii
            for k=1:thisIndex(1,j)
               prod1=prod1*extendedState(j,1);
            end
         end   
      end
      sum=sum+theta(i,1)*prod1; 
   end
   dfdx_m(nx,ii)=sum;
   
end

