%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% File name: dhdthetaStatic_m.m
%
% Description: This m-file generates the parameter sensitivity 
%              of the nonlinear static model. 
%
% Inputs: y_n - output order
%			 x_m - current model state
%         u - current input
%         theta - current parameter vector
%         allIndices - Matrix with all powers
%
% Outputs: dhdthetaStatic_m - parameter sensitivities
%
% Author and copyright: Torbjrn Wigren
%                       Systems and Control
%                       Department of Information Technology
%                       Uppsala University
%                       Uppsala
%                       Sweden
%
% Revision log: Created 2005-08-23.
%
% Firm revision: revision 2.0, 2005-08-23.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [dhdthetaStatic_m]=dhdthetaStatic_m(ny,x_m,u,theta,allIndices)

extendedState=[
   x_m;
   u];
numberOfIndicesInSum=size(allIndices,1);

nx=size(x_m,1);
ntheta=size(theta,1);
dfdtheta_m=zeros(nx,ntheta);

for i=1:ntheta
 
  % One sensitivity component corresponds to one index state
   
   thisIndex=allIndices(i,:);
   prod1=1;   
   for j=1:size(thisIndex,2)
      for k=1:thisIndex(1,j)
         prod1=prod1*extendedState(j,1);
      end
   end
   dhdthetaStatic_m(ny,i)=prod1;
end

